==> cscec5b-wzxt-impl-3.0.0-20210730.071655-282-sources.jar: com/ejianc/business/wzxt/bean/CtPlanEntity.java <==
package com.ejianc.business.wzxt.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.List;
/**
 * 消耗材总控计划实体
 *
 * @author generator
 *
 */
 @TableName("ejc_wzxt_ct_plan")
public class CtPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 计划编码
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_source_id")
    private String projectSourceId; // 项目来源ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_source_id")
    private String orgSourceId; // 组织来源ID
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="employee_telephone")
    private Long employeeTelephone; // 经办人电话
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_date")
    private java.util.Date createDate; // 编制日期
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 上级组织id
    @TableField(value="parent_org_source_id")
    private String parentOrgSourceId; // 上级组织来源id
    @TableField(value="source_id")
    private String sourceId; // 来源主键
    @TableField(value="source_system")
    private String sourceSystem; // 来源系统
    @TableField(value="def1")
    private String def1; // 自定义字段
    @TableField(value="def2")
    private String def2; // 自定义字段
    @TableField(value="def3")
    private String def3; // 自定义字段
    @TableField(value="def4")
    private String def4; // 自定义字段
    @TableField(value="def5")
    private String def5; // 自定义字段
    @TableField(value="source_version")
    private String sourceVersion; // 版本号


    @TableField(exist=false)
    @SubEntity(serviceName="ctPlanDetailService",pidName = "ctId")
    private List<CtPlanDetailEntity> ctPlanDetailEntities = new ArrayList<>(); // 消耗材总控计划明细


    /**
     * 计划编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 计划编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目来源ID
     */
    public String getProjectSourceId() {
        return projectSourceId;
    }

    /**
     * 项目来源ID
     */
    public void setProjectSourceId(String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织来源ID
     */
    public String getOrgSourceId() {
        return orgSourceId;
    }

    /**
     * 组织来源ID
     */
    public void setOrgSourceId(String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 经办人
     */
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 经办人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 经办人电话
     */
    public Long getEmployeeTelephone() {
        return employeeTelephone;
    }

    /**
     * 经办人电话
     */
    public void setEmployeeTelephone(Long employeeTelephone) {
        this.employeeTelephone = employeeTelephone;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制日期
     */
    public java.util.Date getCreateDate() {
        return createDate;
    }

    /**
     * 编制日期
     */
    public void setCreateDate(java.util.Date createDate) {
        this.createDate = createDate;
    }
    /**
     * 上级组织id
     */
    public Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 上级组织id
     */
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 上级组织来源id
     */
    public String getParentOrgSourceId() {
        return parentOrgSourceId;
    }

    /**
     * 上级组织来源id
     */
    public void setParentOrgSourceId(String parentOrgSourceId) {
        this.parentOrgSourceId = parentOrgSourceId;
    }
    /**
     * 来源主键
     */
    public String getSourceId() {
        return sourceId;
    }

    /**
     * 来源主键
     */
    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 来源系统
     */
    public String getSourceSystem() {
        return sourceSystem;
    }

    /**
     * 来源系统
     */
    public void setSourceSystem(String sourceSystem) {
        this.sourceSystem = sourceSystem;
    }
    /**
     * 自定义字段
     */
    public String getDef1() {
        return def1;
    }

    /**
     * 自定义字段
     */
    public void setDef1(String def1) {
        this.def1 = def1;
    }
    /**
     * 自定义字段
     */
    public String getDef2() {
        return def2;
    }

    /**
     * 自定义字段
     */
    public void setDef2(String def2) {
        this.def2 = def2;
    }
    /**
     * 自定义字段
     */
    public String getDef3() {
        return def3;
    }

    /**
     * 自定义字段
     */
    public void setDef3(String def3) {
        this.def3 = def3;
    }
    /**
     * 自定义字段
     */
    public String getDef4() {
        return def4;
    }

    /**
     * 自定义字段
     */
    public void setDef4(String def4) {
        this.def4 = def4;
    }
    /**
     * 自定义字段
     */
    public String getDef5() {
        return def5;
    }

    /**
     * 自定义字段
     */
    public void setDef5(String def5) {
        this.def5 = def5;
    }
    /**
     * 版本号
     */
    public String getSourceVersion() {
        return sourceVersion;
    }

    /**
     * 版本号
     */
    public void setSourceVersion(String sourceVersion) {
        this.sourceVersion = sourceVersion;
    }

    /**
     * 消耗材总控计划明细
     */
    public List<CtPlanDetailEntity> getCtPlanDetailEntities() {
        return ctPlanDetailEntities;
    }

    /**
     * 消耗材总控计划明细
     */
    public void setCtPlanDetailEntities(List<CtPlanDetailEntity> ctPlanDetailEntities) {
        this.ctPlanDetailEntities = ctPlanDetailEntities;
    }
}

==> cscec5b-wzxt-impl-3.0.0-20210730.101357-283-sources.jar: com/ejianc/business/wzxt/bean/CtPlanEntity.java <==
package com.ejianc.business.wzxt.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.List;
/**
 * 消耗材总控计划实体
 *
 * @author generator
 *
 */
 @TableName("ejc_wzxt_ct_plan")
public class CtPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 计划编码
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_source_id")
    private String projectSourceId; // 项目来源ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_source_id")
    private String orgSourceId; // 组织来源ID
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="employee_telephone")
    private Long employeeTelephone; // 经办人电话
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date createDate; // 编制日期
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 上级组织id
    @TableField(value="parent_org_source_id")
    private String parentOrgSourceId; // 上级组织来源id
    @TableField(value="source_id")
    private String sourceId; // 来源主键
    @TableField(value="source_system")
    private String sourceSystem; // 来源系统
    @TableField(value="def1")
    private String def1; // 自定义字段
    @TableField(value="def2")
    private String def2; // 自定义字段
    @TableField(value="def3")
    private String def3; // 自定义字段
    @TableField(value="def4")
    private String def4; // 自定义字段
    @TableField(value="def5")
    private String def5; // 自定义字段
    @TableField(value="source_version")
    private String sourceVersion; // 版本号


    @TableField(exist=false)
    @SubEntity(serviceName="ctPlanDetailService",pidName = "ctId")
    private List<CtPlanDetailEntity> ctPlanDetailEntities = new ArrayList<>(); // 消耗材总控计划明细


    /**
     * 计划编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 计划编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目来源ID
     */
    public String getProjectSourceId() {
        return projectSourceId;
    }

    /**
     * 项目来源ID
     */
    public void setProjectSourceId(String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织来源ID
     */
    public String getOrgSourceId() {
        return orgSourceId;
    }

    /**
     * 组织来源ID
     */
    public void setOrgSourceId(String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 经办人
     */
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 经办人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 经办人电话
     */
    public Long getEmployeeTelephone() {
        return employeeTelephone;
    }

    /**
     * 经办人电话
     */
    public void setEmployeeTelephone(Long employeeTelephone) {
        this.employeeTelephone = employeeTelephone;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制日期
     */
    public java.util.Date getCreateDate() {
        return createDate;
    }

    /**
     * 编制日期
     */
    public void setCreateDate(java.util.Date createDate) {
        this.createDate = createDate;
    }
    /**
     * 上级组织id
     */
    public Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 上级组织id
     */
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 上级组织来源id
     */
    public String getParentOrgSourceId() {
        return parentOrgSourceId;
    }

    /**
     * 上级组织来源id
     */
    public void setParentOrgSourceId(String parentOrgSourceId) {
        this.parentOrgSourceId = parentOrgSourceId;
    }
    /**
     * 来源主键
     */
    public String getSourceId() {
        return sourceId;
    }

    /**
     * 来源主键
     */
    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 来源系统
     */
    public String getSourceSystem() {
        return sourceSystem;
    }

    /**
     * 来源系统
     */
    public void setSourceSystem(String sourceSystem) {
        this.sourceSystem = sourceSystem;
    }
    /**
     * 自定义字段
     */
    public String getDef1() {
        return def1;
    }

    /**
     * 自定义字段
     */
    public void setDef1(String def1) {
        this.def1 = def1;
    }
    /**
     * 自定义字段
     */
    public String getDef2() {
        return def2;
    }

    /**
     * 自定义字段
     */
    public void setDef2(String def2) {
        this.def2 = def2;
    }
    /**
     * 自定义字段
     */
    public String getDef3() {
        return def3;
    }

    /**
     * 自定义字段
     */
    public void setDef3(String def3) {
        this.def3 = def3;
    }
    /**
     * 自定义字段
     */
    public String getDef4() {
        return def4;
    }

    /**
     * 自定义字段
     */
    public void setDef4(String def4) {
        this.def4 = def4;
    }
    /**
     * 自定义字段
     */
    public String getDef5() {
        return def5;
    }

    /**
     * 自定义字段
     */
    public void setDef5(String def5) {
        this.def5 = def5;
    }
    /**
     * 版本号
     */
    public String getSourceVersion() {
        return sourceVersion;
    }

    /**
     * 版本号
     */
    public void setSourceVersion(String sourceVersion) {
        this.sourceVersion = sourceVersion;
    }

    /**
     * 消耗材总控计划明细
     */
    public List<CtPlanDetailEntity> getCtPlanDetailEntities() {
        return ctPlanDetailEntities;
    }

    /**
     * 消耗材总控计划明细
     */
    public void setCtPlanDetailEntities(List<CtPlanDetailEntity> ctPlanDetailEntities) {
        this.ctPlanDetailEntities = ctPlanDetailEntities;
    }
}
